---
slug: /database-overview-of-api
---

# Database Management

A database contains tables, indexes, and metadata of database objects. You can create, query, and delete databases as needed.

The following APIs are available for database operations.

| API | Description | Documentation |
|---|---|---|
| `create_database()` | Creates a database. | [Documentation](200.create-database-of-api.md) |
| `get_database()` | Gets a specified database. |[Documentation](300.get-database-of-api.md)|
| `list_databases()`  | Gets the list of databases in the instance.  |[Documentation](400.list-database-of-api.md)|
| `delete_database()`  | Deletes a specified database.|[Documentation](500.delete-database-of-api.md)|